==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/JSON.java <==
package net.java.html.lib;
public class JSON extends net.java.html.lib.Objs {
  protected JSON(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<JSON> {
    $Constructor() {
      super(JSON.class);
    }
    @Override
    public JSON create(java.lang.Object obj) {
      return obj == null ? null : new JSON(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static JSON $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /**
  * Converts a JavaScript Object Notation (JSON) string into an object.
  * @param text A valid JSON string.
  * @param reviver A function that transforms the results. This function is called for each member of the object.
  * If a member contains nested objects, the nested objects are transformed before the parent object is.
  */
  public static java.lang.Object parse(java.lang.String text, net.java.html.lib.Function.A2<? super java.lang.Object,? super java.lang.Object,? extends java.lang.Object> reviver) {
    return $Typings$.parse$697(text, /* FunctionType*/$js(reviver));
  }
  /**
  * Converts a JavaScript Object Notation (JSON) string into an object.
  * @param text A valid JSON string.
  * @param reviver A function that transforms the results. This function is called for each member of the object.
  * If a member contains nested objects, the nested objects are transformed before the parent object is.
  */
  public static java.lang.Object parse(java.lang.String text) {
    return $Typings$.parse$698(text);
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  */
  public static java.lang.String stringify(java.lang.Object value) {
    return $Typings$.stringify$699(/* AnyKeyword*/$js(value));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer) {
    return $Typings$.stringify$700(/* AnyKeyword*/$js(value), replacer);
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer, java.lang.String space) {
    return $Typings$.stringify$701(/* AnyKeyword*/$js(value), replacer, /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer, double space) {
    return $Typings$.stringify$701(/* AnyKeyword*/$js(value), replacer, /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer) {
    return $Typings$.stringify$702(/* AnyKeyword*/$js(value), /* FunctionType*/$js(replacer));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer, java.lang.String space) {
    return $Typings$.stringify$703(/* AnyKeyword*/$js(value), /* FunctionType*/$js(replacer), /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer, double space) {
    return $Typings$.stringify$703(/* AnyKeyword*/$js(value), /* FunctionType*/$js(replacer), /* UnionType*/$js(space));
  }
}

==> net.java.html.lib-0.3-sources.jar: net/java/html/lib/JSON.java <==
package net.java.html.lib;
public class JSON extends net.java.html.lib.Objs {
  protected JSON(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<JSON> {
    $Constructor() {
      super(JSON.class);
    }
    @Override
    public JSON create(java.lang.Object obj) {
      return obj == null ? null : new JSON(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static JSON $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /**
  * Converts a JavaScript Object Notation (JSON) string into an object.
  * @param text A valid JSON string.
  * @param reviver A function that transforms the results. This function is called for each member of the object.
  * If a member contains nested objects, the nested objects are transformed before the parent object is.
  */
  public static java.lang.Object parse(java.lang.String text, net.java.html.lib.Function.A2<? super java.lang.Object,? super java.lang.Object,? extends java.lang.Object> reviver) {
    return $Typings$.parse$697(text, net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(reviver, new Class[] {java.lang.Object.class, java.lang.Object.class})));
  }
  /**
  * Converts a JavaScript Object Notation (JSON) string into an object.
  * @param text A valid JSON string.
  * @param reviver A function that transforms the results. This function is called for each member of the object.
  * If a member contains nested objects, the nested objects are transformed before the parent object is.
  */
  public static java.lang.Object parse(java.lang.String text) {
    return $Typings$.parse$698(text);
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  */
  public static java.lang.String stringify(java.lang.Object value) {
    return $Typings$.stringify$699(/* AnyKeyword*/$js(value));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer) {
    return $Typings$.stringify$700(/* AnyKeyword*/$js(value), /* ArrayType*/$js(replacer));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer, java.lang.String space) {
    return $Typings$.stringify$701(/* AnyKeyword*/$js(value), /* ArrayType*/$js(replacer), /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer Array that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, java.lang.Object[] replacer, double space) {
    return $Typings$.stringify$701(/* AnyKeyword*/$js(value), /* ArrayType*/$js(replacer), /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer) {
    return $Typings$.stringify$702(/* AnyKeyword*/$js(value), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(replacer, new Class[] {java.lang.String.class, java.lang.Object.class})));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer, java.lang.String space) {
    return $Typings$.stringify$703(/* AnyKeyword*/$js(value), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(replacer, new Class[] {java.lang.String.class, java.lang.Object.class})), /* UnionType*/$js(space));
  }
  /**
  * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.
  * @param value A JavaScript value, usually an object or array, to be converted.
  * @param replacer A function that transforms the results.
  * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.
  */
  public static java.lang.String stringify(java.lang.Object value, net.java.html.lib.Function.A2<? super java.lang.String,? super java.lang.Object,? extends java.lang.Object> replacer, double space) {
    return $Typings$.stringify$703(/* AnyKeyword*/$js(value), net.java.html.lib.Objs.$js(net.java.html.lib.Function.newFunction(replacer, new Class[] {java.lang.String.class, java.lang.Object.class})), /* UnionType*/$js(space));
  }
}
